@@ -82,18 +82,18 @@ class Matrix(SheetMeta):
         :param int column: column index which starts from 0
         :param any new_value: new value if this is to set the value
         """
-        if row < self.number_of_rows() and column < self.number_of_columns():
-            if new_value is None:
-                # get
+        fit = row < self.number_of_rows() and column < self.number_of_columns()
+        if new_value is None:
+            if fit:
                 return self.__array[row][column]
             else:
-                # set
-                self.__array[row][column] = new_value
-        else:
-            if new_value is None:
                 raise IndexError("Index out of range")
-            else:
-                self.paste((row, column), [[new_value]])
+        else:
+            if not fit:
+                width, array = uniform(self.__array, row+1, column+1)
+                self.__width, self.__array = width, array
+
+            self.__array[row][column] = new_value
 
     def row_at(self, index):
         """
@@ -111,8 +111,7 @@ class Matrix(SheetMeta):
             raise IndexError(constants.MESSAGE_INDEX_OUT_OF_RANGE)
 
     def set_row_at(self, row_index, data_array):
-        """Update a row data range
-        """
+        """Update a row data range"""
         nrows = self.number_of_rows()
         if row_index < nrows:
             self.__array[row_index] = data_array
@@ -449,8 +448,7 @@ class Matrix(SheetMeta):
         self.__width, self.__array = uniform(self.__array)
 
     def delete_columns(self, column_indices):
-        """Delete columns by specified list of indices
-        """
+        """Delete columns by specified list of indices"""
         if isinstance(column_indices, list) is False:
             raise TypeError(constants.MESSAGE_DATA_ERROR_DATA_TYPE_MISMATCH)
         if len(column_indices) > 0:
@@ -502,8 +500,7 @@ class Matrix(SheetMeta):
         self.__width, self.__array = uniform(self.__array)
 
     def to_array(self):
-        """Get an array out
-        """
+        """Get an array out"""
         return self.__array
 
     def __iter__(self):
@@ -800,12 +797,17 @@ def longest_row_number(array):
         return 0
 
 
-def uniform(array):
+def uniform(array, min_rows=0, min_columns=0):
     """Fill-in empty strings to empty cells to make it MxN
 
     :param list in_array: a list of arrays
+    :param int row_no: desired minimum row count
+    :param int column_no: desired minimum column length
     """
-    width = longest_row_number(array)
+    width = max(min_columns, longest_row_number(array))
+    array_length = len(array)
+    height = max(array_length, min_rows)
+
     if width == 0:
         return 0, array
     else:
@@ -816,6 +818,9 @@ def uniform(array):
                     row[index] = constants.DEFAULT_NA
             if row_length < width:
                 row += [constants.DEFAULT_NA] * (width - row_length)
+        for _ in range(array_length, height):
+            row = [constants.DEFAULT_NA] * width
+            array.append(row)
         return width, array
 
 
