@@ -15,8 +15,7 @@ from pyexcel.internal import PARSER
 
 # pylint: disable=W0223
 class ReadExcelFromFile(AbstractSource):
-    """Pick up 'file_name' field and do single sheet based read and write
-    """
+    """Pick up 'file_name' field and do single sheet based read and write"""
 
     def __init__(self, file_name=None, parser_library=None, **keywords):
         self.__file_name = file_name
