@@ -1,4 +1,5 @@
 import warnings
+from unittest.mock import patch
 
 import pyexcel.ext.ods
 import pyexcel.ext.xls
@@ -6,8 +7,6 @@ import pyexcel.ext.ods3
 import pyexcel.ext.text
 import pyexcel.ext.xlsx
 
-from mock import patch
-
 try:
     reload
 except NameError:
